# Sentry-DingDing

Fork `https://github.com/cench/sentry-10-dingding`

## 添加
告警内容添加版本和tag环境信息

## 安装

```
# requirement.txt

sentry-dingding-maxbon
```

docker-compose 安装的直接改成这个插件包就好了，如果帮你解决了问题，麻烦给个小星星.

